"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EventClient = void 0;
const events_1 = require("../../protoc/events/events");
const hatchet_error_1 = __importDefault(require("../../util/errors/hatchet-error"));
const logger_1 = require("../../util/logger");
class EventClient {
    constructor(config, channel, factory) {
        this.config = config;
        this.client = factory.create(events_1.EventsServiceDefinition, channel);
        this.logger = new logger_1.Logger(`Dispatcher`, config.log_level);
    }
    push(type, input) {
        const req = {
            key: type,
            payload: JSON.stringify(input),
            eventTimestamp: new Date(),
        };
        try {
            const e = this.client.push(req);
            this.logger.info(`Event pushed: ${type}`);
            return e;
        }
        catch (e) {
            throw new hatchet_error_1.default(e.message);
        }
    }
}
exports.EventClient = EventClient;
