import * as z from 'zod';
import { CreateStep } from './step';
import { ConcurrencyLimitStrategy as PbConcurrencyLimitStrategy } from './protoc/workflows';
declare const StepsSchema: z.ZodArray<z.ZodObject<{
    name: z.ZodString;
    parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    timeout: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    name: string;
    parents?: string[] | undefined;
    timeout?: string | undefined;
}, {
    name: string;
    parents?: string[] | undefined;
    timeout?: string | undefined;
}>, "many">;
export type Steps = z.infer<typeof StepsSchema>;
export declare const ConcurrencyLimitStrategy: typeof PbConcurrencyLimitStrategy;
export declare const WorkflowConcurrency: z.ZodObject<{
    name: z.ZodString;
    maxRuns: z.ZodOptional<z.ZodNumber>;
    limitStrategy: z.ZodOptional<z.ZodNativeEnum<typeof PbConcurrencyLimitStrategy>>;
}, "strip", z.ZodTypeAny, {
    name: string;
    maxRuns?: number | undefined;
    limitStrategy?: PbConcurrencyLimitStrategy | undefined;
}, {
    name: string;
    maxRuns?: number | undefined;
    limitStrategy?: PbConcurrencyLimitStrategy | undefined;
}>;
export declare const HatchetTimeoutSchema: z.ZodString;
export declare const CreateWorkflowSchema: z.ZodObject<{
    id: z.ZodString;
    description: z.ZodString;
    version: z.ZodOptional<z.ZodString>;
    timeout: z.ZodOptional<z.ZodString>;
    on: z.ZodUnion<[z.ZodObject<{
        cron: z.ZodString;
        event: z.ZodUndefined;
    }, "strip", z.ZodTypeAny, {
        cron: string;
        event?: undefined;
    }, {
        cron: string;
        event?: undefined;
    }>, z.ZodObject<{
        cron: z.ZodUndefined;
        event: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        event: string;
        cron?: undefined;
    }, {
        event: string;
        cron?: undefined;
    }>]>;
    steps: z.ZodArray<z.ZodObject<{
        name: z.ZodString;
        parents: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
        timeout: z.ZodOptional<z.ZodString>;
    }, "strip", z.ZodTypeAny, {
        name: string;
        parents?: string[] | undefined;
        timeout?: string | undefined;
    }, {
        name: string;
        parents?: string[] | undefined;
        timeout?: string | undefined;
    }>, "many">;
}, "strip", z.ZodTypeAny, {
    description: string;
    steps: {
        name: string;
        parents?: string[] | undefined;
        timeout?: string | undefined;
    }[];
    id: string;
    on: {
        cron: string;
        event?: undefined;
    } | {
        event: string;
        cron?: undefined;
    };
    version?: string | undefined;
    timeout?: string | undefined;
}, {
    description: string;
    steps: {
        name: string;
        parents?: string[] | undefined;
        timeout?: string | undefined;
    }[];
    id: string;
    on: {
        cron: string;
        event?: undefined;
    } | {
        event: string;
        cron?: undefined;
    };
    version?: string | undefined;
    timeout?: string | undefined;
}>;
export interface Workflow extends z.infer<typeof CreateWorkflowSchema> {
    concurrency?: z.infer<typeof WorkflowConcurrency> & {
        key: (ctx: any) => string;
    };
    steps: CreateStep<any>[];
}
export {};
